EncryptionService class

Constructors

EncryptionService({required String encryptionKey})

Properties

encryptionKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encrypt(String data, String publicXml) → Uint8List
encryptPayload(String payload) → Uint8List
Encrypts the given payload using RSA encryption.
getXmlComponent(String xmlString, String field) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited