AppTextField class

Inheritance

Constructors

AppTextField({Key? key, TextEditingController? controller, void onChange(String)?, TextInputType keyboardType = TextInputType.text, String? validator(String?)?, double borderRadius = 8.0, Color textColor = Colors.black, Color backgroundColor = Colors.transparent, Widget? suffix, Widget? prefix, int maxLines = 1, required String hintText, TextStyle hintTextStyle = const TextStyle(color: Colors.grey), String? labelText, TextStyle? labelStyle, TextStyle textStyle = const TextStyle(), bool obscureText = false, bool isEnabled = true, List<TextInputFormatter> inputFormatters = const []})
const

Properties

backgroundColor → Color
final
borderRadius → double
final
controller → TextEditingController?
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String
final
hintTextStyle → TextStyle
final
inputFormatters → List<TextInputFormatter>
final
isEnabled → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType
final
labelStyle → TextStyle?
final
labelText → String?
final
maxLines → int
final
obscureText → bool
final
onChange → void Function(String)?
final
prefix → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffix → Widget?
final
textColor → Color
final
textStyle → TextStyle
final
validator → String? Function(String?)?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited